*******
Authors
*******

Contributors to Mopidy in the order of appearance:

- Stein Magnus Jodal <stein.magnus@jodal.no>
- Johannes Knutsen <johannes@knutsen.me>
- Thomas Adamcik <adamcik@samfundet.no>
- Kristian Klette <klette@klette.us>

A complete list of persons with commits accepted into the Mopidy repo can be
found at `GitHub <https://github.com/mopidy/mopidy/graphs/contributors>`_.


Showing your appreciation
=========================

If you already enjoy Mopidy, or don't enjoy it and want to help us making
Mopidy better, the best way to do so is to contribute back to the community.
You can contribute code, documentation, tests, bug reports, or help other
users, spreading the word, etc.
